@@ -28,8 +28,8 @@ mod tests {
     use crate::eval::tests::eval_out;
     use ergotree_ir::mir::expr::Expr;
     use ergotree_ir::mir::global_vars::GlobalVars;
-    use ergotree_ir::util::AsVecI8;
     use sigma_test_util::force_any_val;
+    use sigma_util::AsVecI8;
     use std::rc::Rc;
 
     #[test]
