@@ -10,7 +10,7 @@ impl Evaluable for ExtractCreationInfo {
     fn eval(&self, env: &Env, ctx: &mut EvalContext) -> Result<Value, EvalError> {
         let input_v = self.input.eval(env, ctx)?;
         match input_v {
-            Value::CBox(b) => Ok(ctx.ctx.box_arena.get(&b)?.creation_info().into()),
+            Value::CBox(b) => Ok(b.creation_info().into()),
             _ => Err(EvalError::UnexpectedValue(format!(
                 "Expected ExtractCreationInfo input to be Value::CBox, got {0:?}",
                 input_v
@@ -28,7 +28,7 @@ mod tests {
 
     use ergotree_ir::mir::expr::Expr;
     use ergotree_ir::mir::global_vars::GlobalVars;
-    use ergotree_ir::mir::unary_op::UnaryOpTryBuild;
+    use ergotree_ir::mir::unary_op::OneArgOpTryBuild;
     use sigma_test_util::force_any_val;
 
     use super::*;
@@ -40,12 +40,6 @@ mod tests {
             .into();
         let ctx = Rc::new(force_any_val::<Context>());
         let v = eval_out::<(i32, Vec<i8>)>(&expr, ctx.clone());
-        assert_eq!(
-            v,
-            ctx.self_box
-                .get_box(&ctx.box_arena)
-                .unwrap()
-                .creation_info()
-        );
+        assert_eq!(v, ctx.self_box.creation_info());
     }
 }
