@@ -1,3 +1,5 @@
+//! ProofTree
+
 extern crate derive_more;
 
 use std::fmt::Debug;
@@ -18,6 +20,7 @@ use super::unchecked_tree::UncheckedConjecture;
 use super::unchecked_tree::UncheckedDhTuple;
 use super::unchecked_tree::UncheckedTree;
 use super::unproven_tree::CorUnproven;
+use super::unproven_tree::CthresholdUnproven;
 use super::unproven_tree::UnprovenDhTuple;
 use super::unproven_tree::UnprovenLeaf;
 use super::unproven_tree::UnprovenTree;
@@ -110,8 +113,14 @@ impl From<UncheckedConjecture> for ProofTree {
     }
 }
 
+impl From<CthresholdUnproven> for ProofTree {
+    fn from(v: CthresholdUnproven) -> Self {
+        UnprovenTree::UnprovenConjecture(v.into()).into()
+    }
+}
+
 /// Proof tree leaf
-pub(crate) trait ProofTreeLeaf: Debug {
+pub trait ProofTreeLeaf: Debug {
     /// Get proposition
     fn proposition(&self) -> SigmaBoolean;
 
@@ -122,7 +131,7 @@ pub(crate) trait ProofTreeLeaf: Debug {
 pub(crate) enum ConjectureType {
     And = 0,
     Or = 1,
-    // Threshold = 2,
+    Threshold = 2,
 }
 
 pub(crate) trait ProofTreeConjecture {
@@ -173,6 +182,13 @@ where
                     }))
                     .into()
                 }
+                UnprovenConjecture::CthresholdUnproven(ct) => UnprovenTree::UnprovenConjecture(
+                    UnprovenConjecture::CthresholdUnproven(CthresholdUnproven {
+                        children: ct.children.clone().try_mapped(|c| rewrite(c, f))?,
+                        ..ct.clone()
+                    }),
+                )
+                .into(),
             },
         },
         ProofTree::UncheckedTree(unch_tree) => match unch_tree {
@@ -204,6 +220,23 @@ where
                     }
                     .into()
                 }
+                UncheckedConjecture::CthresholdUnchecked {
+                    challenge,
+                    children,
+                    k,
+                    polynomial: polynomial_opt,
+                } => {
+                    let rewritten_children =
+                        children.clone().try_mapped(|c| rewrite(c.into(), f))?;
+                    let casted_children = cast_to_ust(rewritten_children)?;
+                    UncheckedConjecture::CthresholdUnchecked {
+                        children: casted_children,
+                        challenge: challenge.clone(),
+                        k: *k,
+                        polynomial: polynomial_opt.clone(),
+                    }
+                    .into()
+                }
             },
         },
     })
