@@ -149,7 +149,12 @@ pub trait Prover {
         let ctx_ext = ctx.extension.clone();
         let reduction_result =
             reduce_to_crypto(expr.as_ref(), env, ctx).map_err(ProverError::EvalError)?;
-        self.generate_proof(reduction_result.sigma_prop, message, hints_bag, ctx_ext)
+
+        self.generate_proof(reduction_result.sigma_prop, message, hints_bag)
+            .map(|p| ProverResult {
+                proof: p,
+                extension: ctx_ext,
+            })
     }
 
     /// Generate proofs for the given message for the given Sigma boolean expression
@@ -158,8 +163,7 @@ pub trait Prover {
         sigmabool: SigmaBoolean,
         message: &[u8],
         hints_bag: &HintsBag,
-        ctx_ext: ContextExtension,
-    ) -> Result<ProverResult, ProverError> {
+    ) -> Result<ProofBytes, ProverError> {
         let unchecked_tree_opt = match sigmabool {
             SigmaBoolean::TrivialProp(true) => Ok(None),
             SigmaBoolean::TrivialProp(false) => Err(ProverError::ReducedToFalse),
@@ -169,13 +173,9 @@ pub trait Prover {
                 Ok(Some(unchecked_tree))
             }
         }?;
-        let proof = match unchecked_tree_opt {
+        Ok(match unchecked_tree_opt {
             Some(tree) => serialize_sig(tree),
             None => ProofBytes::Empty,
-        };
-        Ok(ProverResult {
-            proof,
-            extension: ctx_ext,
         })
     }
 }
@@ -489,12 +489,11 @@ fn step4_real_conj(
                 })
                 .mapped(|c| c.into());
             Ok(Some(
-                uc.with_children(new_children).into()
-                // CorUnproven {
-                //     children: new_children,
-                //     ..cor.clone()
-                // }
-                // .into(),
+                uc.with_children(new_children).into(), // CorUnproven {
+                                                       //     children: new_children,
+                                                       //     ..cor.clone()
+                                                       // }
+                                                       // .into(),
             ))
         }
     }
