@@ -147,9 +147,10 @@ impl CommitmentHint {
 }
 
 /// Collection of hints to be used by a prover
+#[derive(Clone)]
 pub struct HintsBag {
     /// Hints stored in a bag
-    hints: Vec<Hint>,
+    pub hints: Vec<Hint>,
 }
 
 impl HintsBag {
@@ -158,6 +159,11 @@ impl HintsBag {
         HintsBag { hints: vec![] }
     }
 
+    /// Adding new hint to hints
+    pub fn add_hint(&mut self, hint: Hint) {
+        self.hints.push(hint);
+    }
+
     /// Commitments from all CommitmentHints in the bag
     pub fn commitments(&self) -> Vec<CommitmentHint> {
         self.hints
